==> hyades.source_3.0.2_20050225_1641.zip: org/eclipse/hyades/statistical/ui/variableloader/internal/SDModifiableVariableRepresentation.java <==
/**********************************************************************
 * Copyright (c) 2003,2004 Scapa Technologies Limited and others
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * Scapa Technologies Limited - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.statistical.ui.variableloader.internal;

public interface SDModifiableVariableRepresentation extends SDMeasuredVariableRepresentation {
/* inherited from SDMeasuredVariableRepresentation
	public void setMeasuredValue(int i) throws ClassCastException;
	public void setMeasuredValue(long i) throws ClassCastException;
	public void setMeasuredValue(float i) throws ClassCastException;
	public void setMeasuredValue(double i) throws ClassCastException;
	public void setMeasuredValue(Object newval) throws ClassCastException;
*/	
	public int getModifierType();

	public String[] getEnumerationValues();
	public void setEnumerationValues(String[] possible);

	public void padRequestedValue(long t) throws ClassCastException;
	public void padRequestedValue(long t, Object newval) throws ClassCastException;

	public void setRequestedValue(long t, int i) throws ClassCastException;
	public void setRequestedValue(long t, long i) throws ClassCastException;
	public void setRequestedValue(long t, float i) throws ClassCastException;
	public void setRequestedValue(long t, double i) throws ClassCastException;
	public void setRequestedValue(long t, Object newval) throws ClassCastException;

	public double getMaxBound();
	public double getMinBound();
	public Object getLastRequestedValue();
	public long getLastRequestedTime();
}

==> hyades.source_3.1.0_20041019_1201.zip: org/eclipse/hyades/statistical/ui/variableloader/internal/SDModifiableVariableRepresentation.java <==
/**********************************************************************
 * Copyright (c) 2003,2004 Scapa Technologies Limited and others
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * Scapa Technologies Limited - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.statistical.ui.variableloader.internal;

import org.eclipse.hyades.model.statistical.SDSnapshotObservation;

public interface SDModifiableVariableRepresentation extends SDMeasuredVariableRepresentation {
/* inherited from SDMeasuredVariableRepresentation
	public void setMeasuredValue(int i) throws ClassCastException;
	public void setMeasuredValue(long i) throws ClassCastException;
	public void setMeasuredValue(float i) throws ClassCastException;
	public void setMeasuredValue(double i) throws ClassCastException;
	public void setMeasuredValue(Object newval) throws ClassCastException;
	public SDSnapshotObservation getMeasuredObservation();
*/	
	public int getModifierType();

	public String[] getEnumerationValues();
	public void setEnumerationValues(String[] possible);

	public void padRequestedValue(long t) throws ClassCastException;
	public void padRequestedValue(long t, Object newval) throws ClassCastException;

	public void setRequestedValue(long t, int i) throws ClassCastException;
	public void setRequestedValue(long t, long i) throws ClassCastException;
	public void setRequestedValue(long t, float i) throws ClassCastException;
	public void setRequestedValue(long t, double i) throws ClassCastException;
	public void setRequestedValue(long t, Object newval) throws ClassCastException;

	public double getMaxBound();
	public double getMinBound();
	public Object getLastRequestedValue();
	public long getLastRequestedTime();
	
	public SDSnapshotObservation getModifiableObservation();
	
}
